@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -31,11 +31,12 @@ public:
     [[nodiscard]] bool import(const QString &fileName, QString &errorMessage, ImportAbstractAutocorrection::LoadAttribute loadAttribute = All) override;
 
 private:
-    enum Type {
+    enum class Type : int8_t {
         DOCUMENT,
         SENTENCE,
         WORD,
     };
+    Q_ENUM(Type)
 
     TEXTAUTOCORRECTIONCORE_NO_EXPORT void importAutoCorrectionFile();
     TEXTAUTOCORRECTIONCORE_NO_EXPORT void closeArchive();
