@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,17 +10,29 @@
 #include <QObject>
 namespace TextEmoticonsCore
 {
-/**
- * @brief The CustomEmojiIconManager class
- * @author Laurent Montel <montel@kde.org>
+/*!
+ * \class TextEmoticonsCore::CustomEmojiIconManager
+ * \inmodule TextEmoticonsCore
+ * \inheaderfile TextEmoticonsCore/CustomEmojiIconManager
+ *
+ * \brief The CustomEmojiIconManager class
+ * \author Laurent Montel <montel@kde.org>
  */
 class TEXTEMOTICONSCORE_EXPORT CustomEmojiIconManager : public QObject
 {
-    Q_GADGET
+    Q_OBJECT
 public:
+    /*!
+     */
     explicit CustomEmojiIconManager(QObject *parent = nullptr);
+    /*!
+     */
     ~CustomEmojiIconManager() override;
+    /*!
+     */
     virtual QIcon generateIcon(const QString &customIdentifier);
+    /*!
+     */
     virtual QString fileName(const QString &customIdentifier);
 };
 }
